"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.FilmTC = void 0;
var node_fetch_1 = __importDefault(require("node-fetch"));
var index_1 = require("../index");
var People_1 = require("./People");
var restApiResponse = {
    title: 'The Empire Strikes Back',
    episode_id: 5,
    opening_crawl: 'It is a dark time for ...',
    director: 'Irvin Kershner',
    producer: 'Gary Kurtz, Rick McCallum',
    release_date: '1980-05-17',
    characters: [
        'https://swapi.co/api/people/1/',
        'https://swapi.co/api/people/2/',
        'https://swapi.co/api/people/3/',
    ],
};
exports.FilmTC = index_1.composeWithJson('Film', restApiResponse);
// //////////////
// RESOLVERS aka FieldConfig in GraphQL
// //////////////
exports.FilmTC.addResolver({
    name: 'findById',
    type: exports.FilmTC,
    args: {
        id: 'Int!',
    },
    resolve: function (rp) {
        return node_fetch_1.default("https://swapi.co/api/films/" + rp.args.id + "/").then(function (r) { return r.json(); });
    },
});
exports.FilmTC.addResolver({
    name: 'findByUrl',
    type: exports.FilmTC,
    args: {
        url: 'String!',
    },
    resolve: function (rp) { return node_fetch_1.default(rp.args.url).then(function (r) { return r.json(); }); },
});
exports.FilmTC.addResolver({
    name: 'findByUrlList',
    type: [exports.FilmTC],
    args: {
        urls: '[String]!',
    },
    resolve: function (rp) {
        return Promise.all(rp.args.urls.map(function (url) { return node_fetch_1.default(url).then(function (r) { return r.json(); }); }));
    },
});
// //////////////
// RELATIONS
// //////////////
exports.FilmTC.addRelation('characters', {
    resolver: function () { return People_1.PeopleTC.getResolver('findByUrlList'); },
    prepareArgs: {
        urls: function (source) { return source.characters; },
    },
});
exports.FilmTC.addFields({
    currentTime: { type: 'String', resolve: function () { return Date.now(); } },
});
